# Changelog

## [1.2.0](https://github.com/copick/napari-copick/compare/napari-copick-v1.1.1...napari-copick-v1.2.0) (2025-12-09)


### ✨ Features

* Allow storing multilabel segmentations from napari-copick.  ([#21](https://github.com/copick/napari-copick/issues/21)) ([a9165e2](https://github.com/copick/napari-copick/commit/a9165e299b5c915408113f73677b487c2bdb5b9a))

## [1.1.1](https://github.com/copick/napari-copick/compare/napari-copick-v1.1.0...napari-copick-v1.1.1) (2025-12-03)


### 🐞 Bug Fixes

* bump version to create zenodo DOI ([#19](https://github.com/copick/napari-copick/issues/19)) ([6c648fc](https://github.com/copick/napari-copick/commit/6c648fcff8ce7017a8649027c5d17101329a4b2c))

## [1.1.0](https://github.com/copick/napari-copick/compare/napari-copick-v1.0.1...napari-copick-v1.1.0) (2025-11-07)


### ✨ Features

* Add segmentation storage options ([#16](https://github.com/copick/napari-copick/issues/16)) ([df34dec](https://github.com/copick/napari-copick/commit/df34dec4451dfd2924ab2f7ed4ea41ea5269460e))


### 🐞 Bug Fixes

* Save copick config after updating objects in UI. ([#17](https://github.com/copick/napari-copick/issues/17)) ([f0b4690](https://github.com/copick/napari-copick/commit/f0b4690e787ea707b622870a1f64c3cf64d517a1))

## [1.0.1](https://github.com/copick/napari-copick/compare/napari-copick-v1.0.0...napari-copick-v1.0.1) (2025-07-27)


### 🐞 Bug Fixes

* fix screenshot link for pypi ([cadb6fb](https://github.com/copick/napari-copick/commit/cadb6fba40e3b904e3a52508a15283beff158aa9))

## [1.0.0](https://github.com/copick/napari-copick/compare/napari-copick-v0.0.1...napari-copick-v1.0.0) (2025-07-27)


### ⚠ BREAKING CHANGES

* Add shared components to the napari-copick UI ([#11](https://github.com/copick/napari-copick/issues/11))
* Separate the widget code from the execution code.  ([#7](https://github.com/copick/napari-copick/issues/7))

### ✨ Features

* Add shared components to the napari-copick UI ([#11](https://github.com/copick/napari-copick/issues/11)) ([c5d4c4c](https://github.com/copick/napari-copick/commit/c5d4c4cf63febb937214234303397d74792742d7))
* Load Tree contents and images async ([#10](https://github.com/copick/napari-copick/issues/10)) ([3905d15](https://github.com/copick/napari-copick/commit/3905d159be1db15942649df423c64724421ac591))
* Save buttons, Make Tree more human-readable, Refactor widget code for readability ([#12](https://github.com/copick/napari-copick/issues/12)) ([5d0f684](https://github.com/copick/napari-copick/commit/5d0f6842102e5213c8799a52dace70e42b620011))
* Separate the widget code from the execution code.  ([#7](https://github.com/copick/napari-copick/issues/7)) ([f2244fc](https://github.com/copick/napari-copick/commit/f2244fc6db5bd52e7c391fd04b6c5d09cb3ef1cc))


### 🧹 Miscellaneous Chores

* FInal fixes before 1.0.0 ([#14](https://github.com/copick/napari-copick/issues/14)) ([b0efbeb](https://github.com/copick/napari-copick/commit/b0efbeb2efb68ccdf290c5395f98a780e69b4477))
* Fix test workflow by switching to uv ([#8](https://github.com/copick/napari-copick/issues/8)) ([3493276](https://github.com/copick/napari-copick/commit/3493276a86b6c91259f267a91477bbec338739a0))
* Set up CI for napari-copick ([#6](https://github.com/copick/napari-copick/issues/6)) ([b97f55b](https://github.com/copick/napari-copick/commit/b97f55b6c0e316bd57c5f8fb54a807a5512fc868))
